GROUP_CATEGORIES = [
    'academ',
    'artchaos',
    'countryside',
    'moments',
    'nanoreports',
    'nsu',
    'patterns',
    'reports',
    'series',
    '_meta',
    'sessions',
    'piter2017',
    'poll',
]

CLOSED_NAMES = [
    'annette',
    'cafe',
    'photoclub',
    'private',
    'sessions',
    'technologika',
    'fit',
    'fen',
    'shabanov',
    'lika',
    'luci',
    'leonova',
    'palliative'
]

OUR_PEOPLE_NAMES = [
    'absaidulieva',
    'ahmary',
    'anischenko',
    'annette',
    'aziza',
    'babich',
    'babicheva',
    'banan',
    'belovezhets',
    'biryukov',
    'biserova',
    'budaeva',
    'cafe',
    'contest',
    'damdinov',
    'dubynina',
    'ermishina',
    'esler',
    'faina',
    'fokina',
    'gapenko',
    'gassan',
    'golodyaeva',
    'guzhvina',
    'iokimaru',
    'kachanova',
    'kamaeva',
    'karmanova',
    'kolpakov',
    'korobova',
    'kosikhin',
    'leonova',
    'lika',
    'lina',
    'me',
    'melgunov',
    'miroshnichenko',
    'nam',
    'nastya_med',
    'nigga',
    'okhvat',
    'oydopova',
    'pesterev',
    'porechnaya_ggf',
    'photoclub',
    'rats',
    'sazhina',
    'sharipova',
    'sher',
    'shlee',
    'shmakov',
    'spice',
    'toropova',
    'vesnina',
    'yartseva',
    'zimbickiy'
]

TEST_OUR_PEOPLE_NAMES = [
    'absaidulieva',
    'ahmary',
    'anischenko',
    'annette',
    'aziza',
    'babich',
    'babicheva',
    'banan',
    'belovezhets',
    'biryukov',
    'biserova',
    'budaeva',
    'cafe',
    'contest',
    'damdinov',
    'dubynina',
    'ermishina',
    'esler',
    'faina',
    'fokina',
    'gapenko',
    'gassan',
    'golodyaeva',
    'guzhvina',
    'iokimaru',
    'kachanova',
    'kamaeva',
    'karmanova',
    'kolpakov',
    'korobova',
    'kosikhin',
    'leonova',
    'lika',
    'lina',
    'me',
    'melgunov',
    'miroshnichenko',
    'nam',
    'nastya_med',
    'nigga',
    'okhvat',
    'oydopova',
    'pesterev',
    'porechnaya_ggf',
    'photoclub',
    'rats',
    'sazhina',
    'sharipova',
    'sher',
    'shlee',
    'shmakov',
    'spice',
    'toropova',
    'vesnina',
    'yartseva',
    'zimbickiy'
]

diff = list(set(TEST_OUR_PEOPLE_NAMES).difference(OUR_PEOPLE_NAMES))

print(diff)

a = 7

STAGES_NAMES = [
    'stage0.gif',
    'stage0.recapture',
    'stage1.filter',
    'stage2.develop',
    'stage2.ourate',
    'stage3.ready',
    'stage4.published',
]
