from setuptools import setup, find_packages

setup(
    name='justin',
    version='0.0.0',
    packages=find_packages(),
    install_requires=[
        'pyvko',
        'Pillow',
    ],
    url='',
    license='MIT',
    author='Harry Djachenko',
    author_email='i.s.djachenko@gmail.com',
    description=''
)
